==> v8.3.zip: ru_twords_ru_tw/bible/kt/dayofthelord.md <==
# день Господа, день Христов, день Христа, день Яхве

## Определение:

Ветхозаветные термины “день Яхве” и “день Господень” используются для обозначения конкретного периода времени, когда Бог будет судить людей за их грехи.

* Иногда “день Яхве” используется для обозначения времени, когда Яхве вмешивается и освобождает Свой народ от врагов.
* В других случаях эта фраза используется в пророчествах о будущем суде или наказании, которые Яхве наведёт на Свой народ. В некоторых контекстах она может также относиться ко времени последнего суда.
* Термин “день Господа” в Новом Завете обычно относится к дню или времени, когда Господь Иисус вернётся судить людей в конце времён.
* Этот последний момент будущего суда и воскресения переводится также фразой “последний день”. Это время начнётся, когда Господь Иисус вернётся на землю, чтобы судить грешников и утвердить Своё правление навечно.
* Слово “день” в этой фразе может означать “день”, либо ссылаться на “время” или “событие”, длящееся более суток.
* Иногда наказание описывается как “излияние Божьего гнева” на тех, которые не поверили в Бога.

## Варианты перевода:

* В зависимости от контекста “день Яхве” можно перевести следующими способами: “время Яхве”, “событие, в котором Яхве будет наказывать Своих врагов” или “время гнева Яхве”.
* Фразу “день Господа” можно также перевести как “время суда Господа” или “время, когда Господь Иисус вернётся, чтобы судить людей”.

(См. также: [день](../other/biblicaltimeday.md), [день суда](../kt/judgmentday.md), [Господь](../kt/lord.md), [воскресение](../kt/resurrection.md), [Яхве](../kt/yahweh.md))

## Ссылки на библейский текст:

* [1 Кор. 5:3-5](rc://*/tn/help/1co/05/03)
* [1 Фес. 5:1-3](rc://*/tn/help/1th/05/01)
* [2 Пет. 3:10](rc://*/tn/help/2pe/03/10)
* [2 Фес. 2:1-2](rc://*/tn/help/2th/02/01)
* [Деян. 2:20-21](rc://*/tn/help/act/02/20)
* [Флп. 1:9-11](rc://*/tn/help/php/01/09)

## Данные о слове:

* Номера Стронга: H3068, H3117, G2250, G2962

==> v9.2.zip: ru_twords_ru_tw/bible/kt/dayofthelord.md <==
# день Господа, день Христов, день Христа, день Яхве

## Определение:

Ветхозаветные термины “день Яхве” и “день Господень” используются для обозначения конкретного периода времени, когда Бог будет судить людей за их грехи.
* Иногда “день Яхве” используется для обозначения времени, когда Яхве вмешивается и освобождает Свой народ от врагов.
* В других случаях эта фраза используется в пророчествах о будущем суде или наказании, которые Яхве наведёт на Свой народ. В некоторых контекстах она может также относиться ко времени последнего суда.
* Термин “день Господа” в Новом Завете обычно относится к дню или времени, когда Господь Иисус вернётся судить людей в конце времён. 
* Этот последний момент будущего суда и воскресения переводится также фразой “последний день”. Это время начнётся, когда Господь Иисус вернётся на землю, чтобы судить грешников и утвердить Своё правление навечно.
* Слово “день” в этой фразе может означать “день”, либо ссылаться на “время” или “событие”, длящееся более суток.
* Иногда наказание описывается как “излияние Божьего гнева” на тех, которые не поверили в Бога. 
 
## Варианты перевода:

* В зависимости от контекста “день Яхве” можно перевести следующими способами: “время Яхве”, “событие, в котором Яхве будет наказывать Своих врагов” или “время гнева Яхве”.
* Фразу “день Господа” можно также перевести как “время суда Господа” или “время, когда Господь Иисус вернётся, чтобы судить людей”.

(См. также: [день](../other/biblicaltimeday.md), [день суда](../kt/judgmentday.md), [Господь](../kt/lord.md), [воскресение](../kt/resurrection.md), [Яхве](../kt/yahweh.md))

## Ссылки на библейский текст:

* [1 Кор. 5:3-5](rc://ru/tn/help/1co/05/03)
* [1 Фес. 5:1-3](rc://ru/tn/help/1th/05/01)
* [2 Пет. 3:10](rc://ru/tn/help/2pe/03/10)
* [2 Фес. 2:1-2](rc://ru/tn/help/2th/02/01)
* [Деян. 2:20-21](rc://ru/tn/help/act/02/20)
* [Флп. 1:9-11](rc://ru/tn/help/php/01/09)

## Данные о слове:

* Номера Стронга: H3068, H3117, G2250, G2962
